@@ -25,6 +25,9 @@ import six
 
 import falcon
 
+# Constants
+DEFAULT_HOST = 'falconframework.org'
+
 
 def httpnow():
     """Returns the current UTC time as an HTTP date
@@ -64,7 +67,8 @@ def create_environ(path='/', query_string='', protocol='HTTP/1.1', port='80',
         query_string: The query string to simulate (default '')
         protocol: The HTTP protocol to simulate (default 'HTTP/1.1')
         port: The TCP port to simulate (default '80')
-        headers: Optional headers to set (default None)
+        headers: Optional headers to set as a dict or an iterable of tuples
+            that can be converted to a dict (default None)
         app: Value for the SCRIPT_NAME environ variable, described in
             PEP-333: 'The initial portion of the request URL's "path" that
             corresponds to the application object, so that the application
@@ -104,7 +108,7 @@ def create_environ(path='/', query_string='', protocol='HTTP/1.1', port='80',
     }
 
     if protocol != 'HTTP/1.0':
-        env['HTTP_HOST'] = 'falconer'
+        env['HTTP_HOST'] = DEFAULT_HOST
 
     content_length = body.seek(0, 2)
     body.seek(0)
@@ -119,6 +123,10 @@ def create_environ(path='/', query_string='', protocol='HTTP/1.1', port='80',
 
 
 def _add_headers_to_environ(env, headers):
+    if not isinstance(headers, dict):
+        # Try to convert
+        headers = dict(headers)
+
     for name, value in headers.items():
         name = name.upper().replace('-', '_')
 
